#!/usr/bin/python3

""" Test script for shutil._unpack_zipfile

usage: test_unpack.py [-h] [-p]

optional arguments:
  -h, --help   show this help message and exit
  -p, --patch  use patch

"""

import argparse
import os
import sys
import functools

_expected_files = ('file1.txt', 'file2.txt')
_good_zip = 'good.zip'
_bad_zip = 'bad.zip'


def extract_dirname(filename, patch):
    fname, _ = os.path.splitext(filename)
    return '_'.join((fname, 'patched' if patch else 'unpatched'))


def check_result(exdir):
    b = True

    if not os.path.isdir(exdir):
        b = False
        print('missing extract dir {0}'.format(exdir), file=sys.stderr)
    
    for f in _expected_files:
        fpath = os.path.join(exdir, f)
        
        if not os.path.isfile(fpath):
            b = False
            print('missing file {0}'.format(fpath), file=sys.stderr)

    if b:
        print('TEST SUCCEEDED', file=sys.stderr)
    else:
        print('TEST FAILED', file=sys.stderr)

    return b


def test_good_zip(su, patch):
    print('testing {0}, using {1} version'.format(_good_zip, 'patched' if patch else 'unpatched'), file=sys.stderr)
    exdir = extract_dirname(_good_zip, patch)

    if os.path.isdir(exdir):
        print('removing', exdir)
        su.rmtree(exdir)

    su.unpack_archive(_good_zip, exdir)

    check_result(exdir)


def test_bad_zip(su, patch):
    print('testing {0}, using {1} version'.format(_bad_zip, 'patched' if patch else 'unpatched'), file=sys.stderr)
    exdir = extract_dirname(_bad_zip, patch)
    
    if os.path.isdir(exdir):
        print('removing', exdir)
        su.rmtree(exdir)

    su.unpack_archive(_bad_zip, exdir)
    
    check_result(exdir)


def init():
    """ Return parsed command line args."""

    parser = argparse.ArgumentParser(fromfile_prefix_chars='@')
    parser.add_argument('-p', '--patch', action='store_true', dest='patch', default=False, help='use patch')

    return parser.parse_args()


def main():
    """ Script main."""

    args = init()
    print('with patch'if args.patch else 'without patch')
    print()

    if args.patch:
        import shutil_patched as su
    else:
        import shutil as su
    
    test_good_zip(su, args.patch)
    print()
    test_bad_zip(su, args.patch)


if __name__ == '__main__':
    main()
